@@ -50,7 +50,17 @@ or:
     class InvalidHeaderValue < Error; end
     class Timeout < Error; end
     class ResponseParse < Error; end
-    class ProxyConnectionError < Error; end
+
+    class ProxyConnectionError < Error
+      attr_reader :request, :response
+
+      def initialize(msg, request = nil, response = nil)
+        super(msg)
+        @request = request
+        @response = response
+      end
+    end
+
     class ProxyParse < Error; end
     class TooManyRedirects < Error; end
 
@@ -206,8 +216,8 @@ or:
 
     klasses.each do |klass|
       class_name = klass.to_s
-      unless class_name =~ /Error\Z/
-        class_name = klass.to_s + 'Error' if class_name =~ legacy_re
+      unless class_name.match?(/Error\Z/)
+        class_name = klass.to_s + 'Error' if class_name.match?(legacy_re)
       end
       Excon::Errors.const_set(class_name, Excon::Error.const_get(klass))
     end
